@@ -18,7 +18,7 @@ fi
 
 DUP=`sed 's/#.*//' ${FONTDEF} \
        | grep -v '^[ 	]*$$' \
-       | awk '{print $$3}' | sort | uniq -d`
+       | awk '{print $3}' | sort | uniq -d`
 if [ ! -z "$DUP" ] ; then
   echo "Duplicated font definition!" $DUP >&2
   exit
@@ -34,8 +34,8 @@ fi
 
 
 ### KPSEWHICH 
-which kpsewhich >/dev/null 2>&1 /dev/null
-if [ $? = 1 ] ; then
+X=`which kpsewhich` 2> /dev/null
+if [ "X-$X" = "X-" ] ; then
   echo "Not found: kpsewhich" >&2;
   exit 0;
 fi
