@@ -1,10 +1,19 @@
 #!/bin/sh
 
+case $# in
+2)
+  ;;
+*)
+  echo "Usage: mkfonts.sh DBFILE OUTFILE" 
+  echo "Example: mkfonts.sh def.dat fonts" 
+  exit 1
+  ;;
+esac
+
 
 FONTLIST=$1
 OUT=$2
 
-
 VAL=`sed 's/#.*//' $FONTLIST \
      | awk '{ if ((NF != 0) && (NF != 3)) \
                 printf("Line %d: %s\n", NR, $0); }'`
