@@ -70,6 +70,11 @@
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
+#if defined(HAVE_STRING_H) || defined(STDC_HEADERS)
+#  include  <string.h>
+#else
+#  include  <strings.h>
+#endif
 #include "VFlib-3_6.h"
 
 #define PROTOCOL_VERSION  "VFSERVER/2.0"
