@@ -30,11 +30,17 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
  */
 
+#include "../../src/config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <signal.h>
+#if defined(HAVE_STRING_H) || defined(STDC_HEADERS)
+#  include  <string.h>
+#else
+#  include  <strings.h>
+#endif
 #include <VFlib-3_6.h>
 #include "hyakubm.h"
 
